<!--
SPDX-FileCopyrightText: Contributors to the Power Grid Model project <powergridmodel@lfenergy.org>

SPDX-License-Identifier: MPL-2.0
-->

# Test Case: Multiple short circuits (same subgrid)

Test case in which there are multiple faults in the same subgrid.

The circuit diagram is as follows:

```txt
        fault_5          fault_6
            |               |
source_4--node_1--line_3--node_2
```
